(function ($, Drupal, once) {
    'use strict';

    Drupal.behaviors.neverbounceEmailValidation = {
      attach: function (context, settings) {
        let timeout;

        // Use 'once' from the drupal.once library to ensure the behavior is attached only once.
        once('neverbounce', 'input[type="email"]', context).forEach(function (emailField) {
          $(emailField).on('input', function () {
            clearTimeout(timeout);
            timeout = setTimeout(function () {
              const email = $(emailField).val();
              console.log(email);

              if (email) {
                // Use Drupal.ajax for the request
                $.ajax({
                  url: '/neverbounce/validate-email',
                  method: 'POST',
                  data: { email: email },
                  dataType: 'json',
                  beforeSend: function () {
                    // Optional: Show a loading indicator
                    $(emailField).after('<div class="neverbounce-status loading">' + Drupal.t('Validating...') + '</div>');
                  },
                  success: function (response) {
                    $(emailField).next('.neverbounce-status').remove(); // Clear previous messages

                    // Check the result from the API response
                    if (response.message) {
                      const statusMessage = $('<div class="neverbounce-status"></div>').text(response.message);
                      $(emailField).after(statusMessage);
                    }
                  },
                  error: function () {
                    $(emailField).next('.neverbounce-status').remove(); // Clear previous messages
                    const statusMessage = $('<div class="neverbounce-status"></div>').text(Drupal.t('Error validating email.'));
                    $(emailField).after(statusMessage);
                  }
                });
              }
            }, 1500); // 1500ms delay to allow user to finish typing
          });
        });
      }
    };
  })(jQuery, Drupal, once);
